==> nifi-minifi-cpp-0.15.0-source.tar.gz: nifi-minifi-cpp-0.15.0-source/libminifi/include/core/state/nodes/BuildInformation.h <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#pragma once

#include <string>
#include <utility>
#include <vector>

#include "core/state/nodes/MetricsBase.h"

namespace org::apache::nifi::minifi::state::response {

/**
 * Justification and Purpose: Provides build information
 * for this agent.
 */
class BuildInformation : public DeviceInformation {
 public:
  BuildInformation(std::string name, const utils::Identifier &uuid)
      : DeviceInformation(std::move(name), uuid) {
  }

  explicit BuildInformation(std::string name)
      : DeviceInformation(std::move(name)) {
  }

  MINIFIAPI static constexpr const char* Description = "Metric node that defines the pertinent build information for this agent binary";

  std::string getName() const override {
    return "BuildInformation";
  }

  std::vector<SerializedResponseNode> serialize() override;
};

}  // namespace org::apache::nifi::minifi::state::response

==> nifi-minifi-cpp-0.99.2-source.tar.gz: nifi-minifi-cpp-0.99.2-source/libminifi/include/core/state/nodes/BuildInformation.h <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#pragma once

#include <string>
#include <utility>
#include <vector>

#include "core/state/nodes/MetricsBase.h"

namespace org::apache::nifi::minifi::state::response {

/**
 * Justification and Purpose: Provides build information
 * for this agent.
 */
class BuildInformation : public DeviceInformation {
 public:
  BuildInformation(std::string_view name, const utils::Identifier &uuid)
      : DeviceInformation(name, uuid) {
  }

  explicit BuildInformation(std::string_view name)
      : DeviceInformation(name) {
  }

  MINIFIAPI static constexpr const char* Description = "Metric node that defines the pertinent build information for this agent binary";

  std::string getName() const override {
    return "BuildInformation";
  }

  std::vector<SerializedResponseNode> serialize() override;
};

}  // namespace org::apache::nifi::minifi::state::response
